@@ -1,6 +1,6 @@
 package Perl::Critic::Dancer2;
 use Modern::Perl;
-our $VERSION = '0.4001'; # VERSION
+our $VERSION = '0.4100'; # VERSION
 our $AUTHORITY = 'cpan:GEEKRUTH'; # AUTHORITY
 # ABSTRACT: A collection of handy perlcritic modules for Dancer2
 use Carp;
@@ -19,7 +19,7 @@ Perl::Critic::Dancer2 - A collection of handy perlcritic modules for Dancer2
 
 =head1 VERSION
 
-version 0.4001
+version 0.4100
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,12 @@ Complains about usage of deprecated keywords [Default severity: 4]
 
 =item L<Perl::Critic::Policy::Dancer2::ProhibitUnrecommendedKeywords>
 
-Complains about usage of unrecommended keywords [Default severity: 2] 
+Complains about usage of unrecommended keywords [Default severity: 2]
+
+=item L<Perl::Critic::Policy::Dancer2::ReturnNotNecessary>
+
+Certain keywords immediately end execution of the route with an implicit
+C<return>, so using C<return> before them is not necessary. [Default severity: 3]
 
 =back
 
