@@ -21,4 +21,10 @@ sub unrecommended_keywords {
     my $tas = {};
     $tas->{params} = '123';
 }
+sub return_redirect {
+    return redirect 'foo';
+}
+sub just_redirect {
+    redirect 'foo';
+}
 1;
